dynamicLanguageEnabled property
When true, the bot may switch the chat language live (via the
backend change_language tool) and the SDK exposes a manual
language picker in the header. Surfaced via the server config
(dynamic_language_enabled). Picker also requires 2+
supportedLocales.
Implementation
bool get enableFileAttach;/// When `true`, the bot may switch the chat language live (via the
/// backend `change_language` tool) and the SDK exposes a manual
/// language picker in the header. Surfaced via the server config
/// (`dynamic_language_enabled`). Picker also requires 2+
/// [supportedLocales].
bool get dynamicLanguageEnabled;