ChatAppearancePatterns extension

Adds pattern-matching-related methods to ChatAppearance.

on

Methods

map<TResult extends Object?>(TResult $default(_ChatAppearance value)) → TResult

Available on ChatAppearance, provided by the ChatAppearancePatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_ChatAppearance value)?) → TResult?

Available on ChatAppearance, provided by the ChatAppearancePatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_ChatAppearance value)?, {required TResult orElse()}) → TResult

Available on ChatAppearance, provided by the ChatAppearancePatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String? surfaceColor, String? botBubbleColor, String? userBubbleColor, String? botTextColor, String? userTextColor)?, {required TResult orElse()}) → TResult

Available on ChatAppearance, provided by the ChatAppearancePatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>(TResult $default(String? surfaceColor, String? botBubbleColor, String? userBubbleColor, String? botTextColor, String? userTextColor)) → TResult

Available on ChatAppearance, provided by the ChatAppearancePatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String? surfaceColor, String? botBubbleColor, String? userBubbleColor, String? botTextColor, String? userTextColor)?) → TResult?

Available on ChatAppearance, provided by the ChatAppearancePatterns extension

A variant of when that fallback to returning null