currentThemeMode property
The currently-active theme mode, used to mark the selected row in the theme picker. Defaults to ThemeMode.system.
Implementation
final ThemeMode currentThemeMode;
The currently-active theme mode, used to mark the selected row in the theme picker. Defaults to ThemeMode.system.
final ThemeMode currentThemeMode;