onClearHistory property
Callback function called when the clear history action is selected.
If null, the clear history menu item will not be displayed.
Implementation
final VoidCallback? onClearHistory;
Callback function called when the clear history action is selected.
If null, the clear history menu item will not be displayed.
final VoidCallback? onClearHistory;