onClose property
Callback function called when the close/back button is pressed.
If null, the close button will not be displayed.
Implementation
final VoidCallback? onClose;
Callback function called when the close/back button is pressed.
If null, the close button will not be displayed.
final VoidCallback? onClose;