ChatHeaderAction enum

Enum defining available actions in the chat header menu.

Inheritance
Available extensions

Values

clearHistory → const ChatHeaderAction

Clear chat history action.

exportChat → const ChatHeaderAction

Export the current user's transcript as a .zip and hand it to the platform share sheet.

changeLanguage → const ChatHeaderAction

Open the manual language picker.

changeTheme → const ChatHeaderAction

Open the light/dark theme picker.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ChatHeaderAction>
A constant List of the values in this enum, in order of their declaration.