currentThemeMode property
The active theme mode — drives the selected state of a custom theme control.
Implementation
final ThemeMode currentThemeMode;
The active theme mode — drives the selected state of a custom theme control.
final ThemeMode currentThemeMode;