defaultThemeMode property
Initial theme mode before the user overrides it locally — one of 'light', 'dark', or 'system' (follows the host device brightness).
Implementation
@JsonKey(name: 'show_theme_toggle') bool get showThemeToggle;/// Initial theme mode before the user overrides it locally — one of
/// 'light', 'dark', or 'system' (follows the host device brightness).
// ignore: invalid_annotation_target
@JsonKey(name: 'default_theme_mode') String get defaultThemeMode;