enableFileAttach property

  1. @JsonKey.new(name: 'enable_file_attach')
bool get enableFileAttach
inherited

Server-side gate for the paperclip attach button in chat input.

Implementation

@JsonKey(name: 'enable_clear_history') bool get enableClearHistory;/// Server-side gate for the paperclip attach button in chat input.
// ignore: invalid_annotation_target
@JsonKey(name: 'enable_file_attach') bool get enableFileAttach;