notification property
Play notification sound when message received and chat is minimized.
Implementation
bool get buttonClick;/// Play notification sound when message received and chat is minimized.
bool get notification;
Play notification sound when message received and chat is minimized.
bool get buttonClick;/// Play notification sound when message received and chat is minimized.
bool get notification;