SoundConfigurationPatterns extension

Adds pattern-matching-related methods to SoundConfiguration.

on

Methods

map<TResult extends Object?>(TResult $default(_SoundConfiguration value)) → TResult

Available on SoundConfiguration, provided by the SoundConfigurationPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_SoundConfiguration value)?) → TResult?

Available on SoundConfiguration, provided by the SoundConfigurationPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_SoundConfiguration value)?, {required TResult orElse()}) → TResult

Available on SoundConfiguration, provided by the SoundConfigurationPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(bool enabled, double volume, bool messageSent, bool messageReceived, bool chatOpened, bool chatClosed, bool error, bool buttonClick, bool notification, String? messageSentSoundUrl, String? messageReceivedSoundUrl, String? notificationSoundUrl, String? errorSoundUrl)?, {required TResult orElse()}) → TResult

Available on SoundConfiguration, provided by the SoundConfigurationPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>(TResult $default(bool enabled, double volume, bool messageSent, bool messageReceived, bool chatOpened, bool chatClosed, bool error, bool buttonClick, bool notification, String? messageSentSoundUrl, String? messageReceivedSoundUrl, String? notificationSoundUrl, String? errorSoundUrl)) → TResult

Available on SoundConfiguration, provided by the SoundConfigurationPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(bool enabled, double volume, bool messageSent, bool messageReceived, bool chatOpened, bool chatClosed, bool error, bool buttonClick, bool notification, String? messageSentSoundUrl, String? messageReceivedSoundUrl, String? notificationSoundUrl, String? errorSoundUrl)?) → TResult?

Available on SoundConfiguration, provided by the SoundConfigurationPatterns extension

A variant of when that fallback to returning null