delete_history_message property
No description provided for @delete_history_message.
In en, this message translates to: 'This will permanently delete all messages in this conversation.\nThis action cannot be undone.'
Implementation
@override
String get delete_history_message =>
'Permanenteng mabubura nito ang lahat ng mensahe sa pag-uusap na ito.\\nHindi na ito mababawi.';