aiDataReuseNotice property
When true, the chip shows an extra line that chats may be used
to improve the service (display-only). Surfaced via the server
config (ai_data_reuse_notice).
Implementation
String? get privacyUrl;/// When `true`, the chip shows an extra line that chats may be used
/// to improve the service (display-only). Surfaced via the server
/// config (`ai_data_reuse_notice`).
bool get aiDataReuseNotice;