defaultThemeMode property
Initial theme mode before the user overrides it — 'light', 'dark', or 'system' (follows the host device brightness).
Implementation
bool get showThemeToggle;/// Initial theme mode before the user overrides it — 'light', 'dark',
/// or 'system' (follows the host device brightness).
String get defaultThemeMode;