BotConfigurationLocalization extension

on

Properties

localizedAiDisclosure String?

Available on BotConfiguration, provided by the BotConfigurationLocalization extension

Localized AI-disclosure text, or null when the project hasn't set one — in which case the widget falls back to the ai_disclosure ARB string.
no setter
localizedName String

Available on BotConfiguration, provided by the BotConfigurationLocalization extension

Returns the localized bot name based on the current locale.
no setter
localizedSystemInstructions String

Available on BotConfiguration, provided by the BotConfigurationLocalization extension

Returns the localized system instructions based on the current locale.
no setter
localizedWelcomeMessage String

Available on BotConfiguration, provided by the BotConfigurationLocalization extension

Returns the localized welcome message based on the current locale.
no setter