RemoteConfigPatterns extension

Adds pattern-matching-related methods to RemoteConfig.

on

Methods

map<TResult extends Object?>(TResult $default(_RemoteConfig value)) → TResult

Available on RemoteConfig, provided by the RemoteConfigPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_RemoteConfig value)?) → TResult?

Available on RemoteConfig, provided by the RemoteConfigPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_RemoteConfig value)?, {required TResult orElse()}) → TResult

Available on RemoteConfig, provided by the RemoteConfigPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(LocalizedText name, LocalizedText welcomeMessage, LocalizedText systemInstruction, String defaultLocale, List<String> supportedLocales, String? fontFamily, String? color, String? avatar, FabConfiguration? fabConfiguration, ChatAppearance? chatAppearance, ChatAppearance? chatAppearanceDark, bool showThemeToggle, String defaultThemeMode, SoundConfiguration? soundConfiguration, bool enableUserExport, bool enableClearHistory, bool enableFileAttach, bool dynamicLanguageEnabled, bool aiDisclosureEnabled, LocalizedText? aiDisclosureText, bool aiDisclosureRequireAck, bool messageReportingEnabled, String? aiInfoUrl, String? privacyUrl, bool aiDataReuseNotice)?, {required TResult orElse()}) → TResult

Available on RemoteConfig, provided by the RemoteConfigPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>(TResult $default(LocalizedText name, LocalizedText welcomeMessage, LocalizedText systemInstruction, String defaultLocale, List<String> supportedLocales, String? fontFamily, String? color, String? avatar, FabConfiguration? fabConfiguration, ChatAppearance? chatAppearance, ChatAppearance? chatAppearanceDark, bool showThemeToggle, String defaultThemeMode, SoundConfiguration? soundConfiguration, bool enableUserExport, bool enableClearHistory, bool enableFileAttach, bool dynamicLanguageEnabled, bool aiDisclosureEnabled, LocalizedText? aiDisclosureText, bool aiDisclosureRequireAck, bool messageReportingEnabled, String? aiInfoUrl, String? privacyUrl, bool aiDataReuseNotice)) → TResult

Available on RemoteConfig, provided by the RemoteConfigPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(LocalizedText name, LocalizedText welcomeMessage, LocalizedText systemInstruction, String defaultLocale, List<String> supportedLocales, String? fontFamily, String? color, String? avatar, FabConfiguration? fabConfiguration, ChatAppearance? chatAppearance, ChatAppearance? chatAppearanceDark, bool showThemeToggle, String defaultThemeMode, SoundConfiguration? soundConfiguration, bool enableUserExport, bool enableClearHistory, bool enableFileAttach, bool dynamicLanguageEnabled, bool aiDisclosureEnabled, LocalizedText? aiDisclosureText, bool aiDisclosureRequireAck, bool messageReportingEnabled, String? aiInfoUrl, String? privacyUrl, bool aiDataReuseNotice)?) → TResult?

Available on RemoteConfig, provided by the RemoteConfigPatterns extension

A variant of when that fallback to returning null